nvector._core.R2xyz — nvector 0.7.5 documentation

# nvector._core.R2xyz

`R2xyz`(R_AB)

  Returns the angles about new axes in the xyz-order from a rotation matrix.

  Parameters
    R_AB: 3 x 3 x n array

      rotation matrix [no unit] (direction cosine matrix) such that the relation between a vector v decomposed in A and B is given by: v_A = mdot(R_AB, v_B)

  Returns
    x, y, z: real scalars or array of length n.

      Angles [rad] of rotation about new axes.

  See also

  `xyz2R`, `R2zyx`, `xyz2R`

  Notes

  The x, y, z angles are called Euler angles or Tait-Bryan angles and are defined by the following procedure of successive rotations: Given two arbitrary coordinate frames A and B. Consider a temporary frame T that initially coincides with A. In order to make T align with B, we first rotate T an angle x about its x-axis (common axis for both A and T). Secondly, T is rotated an angle y about the NEW y-axis of T. Finally, T is rotated an angle z about its NEWEST z-axis. The final orientation of T now coincides with the orientation of B.

  The signs of the angles are given by the directions of the axes and the right hand rule.